# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class UpdateSystemEventsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'event_ids': 'list[str]',
        'operated_end_at': 'str',
        'operated_start_at': 'str',
        'status': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'event_ids': 'EventIds',
        'operated_end_at': 'OperatedEndAt',
        'operated_start_at': 'OperatedStartAt',
        'status': 'Status',
        'updated_at': 'UpdatedAt'
    }

    def __init__(self, event_ids=None, operated_end_at=None, operated_start_at=None, status=None, updated_at=None, _configuration=None):  # noqa: E501
        """UpdateSystemEventsRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._event_ids = None
        self._operated_end_at = None
        self._operated_start_at = None
        self._status = None
        self._updated_at = None
        self.discriminator = None

        if event_ids is not None:
            self.event_ids = event_ids
        if operated_end_at is not None:
            self.operated_end_at = operated_end_at
        if operated_start_at is not None:
            self.operated_start_at = operated_start_at
        if status is not None:
            self.status = status
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def event_ids(self):
        """Gets the event_ids of this UpdateSystemEventsRequest.  # noqa: E501


        :return: The event_ids of this UpdateSystemEventsRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_ids

    @event_ids.setter
    def event_ids(self, event_ids):
        """Sets the event_ids of this UpdateSystemEventsRequest.


        :param event_ids: The event_ids of this UpdateSystemEventsRequest.  # noqa: E501
        :type: list[str]
        """

        self._event_ids = event_ids

    @property
    def operated_end_at(self):
        """Gets the operated_end_at of this UpdateSystemEventsRequest.  # noqa: E501


        :return: The operated_end_at of this UpdateSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._operated_end_at

    @operated_end_at.setter
    def operated_end_at(self, operated_end_at):
        """Sets the operated_end_at of this UpdateSystemEventsRequest.


        :param operated_end_at: The operated_end_at of this UpdateSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._operated_end_at = operated_end_at

    @property
    def operated_start_at(self):
        """Gets the operated_start_at of this UpdateSystemEventsRequest.  # noqa: E501


        :return: The operated_start_at of this UpdateSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._operated_start_at

    @operated_start_at.setter
    def operated_start_at(self, operated_start_at):
        """Sets the operated_start_at of this UpdateSystemEventsRequest.


        :param operated_start_at: The operated_start_at of this UpdateSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._operated_start_at = operated_start_at

    @property
    def status(self):
        """Gets the status of this UpdateSystemEventsRequest.  # noqa: E501


        :return: The status of this UpdateSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateSystemEventsRequest.


        :param status: The status of this UpdateSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def updated_at(self):
        """Gets the updated_at of this UpdateSystemEventsRequest.  # noqa: E501


        :return: The updated_at of this UpdateSystemEventsRequest.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this UpdateSystemEventsRequest.


        :param updated_at: The updated_at of this UpdateSystemEventsRequest.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateSystemEventsRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSystemEventsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSystemEventsRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeInfoForRestoreToNewInstanceInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_id': 'str',
        'node_operate_type': 'str',
        'node_spec': 'str',
        'node_type': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'node_id': 'NodeId',
        'node_operate_type': 'NodeOperateType',
        'node_spec': 'NodeSpec',
        'node_type': 'NodeType',
        'zone_id': 'ZoneId'
    }

    def __init__(self, node_id=None, node_operate_type=None, node_spec=None, node_type=None, zone_id=None, _configuration=None):  # noqa: E501
        """NodeInfoForRestoreToNewInstanceInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._node_id = None
        self._node_operate_type = None
        self._node_spec = None
        self._node_type = None
        self._zone_id = None
        self.discriminator = None

        if node_id is not None:
            self.node_id = node_id
        if node_operate_type is not None:
            self.node_operate_type = node_operate_type
        if node_spec is not None:
            self.node_spec = node_spec
        if node_type is not None:
            self.node_type = node_type
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def node_id(self):
        """Gets the node_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501


        :return: The node_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this NodeInfoForRestoreToNewInstanceInput.


        :param node_id: The node_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def node_operate_type(self):
        """Gets the node_operate_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501


        :return: The node_operate_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :rtype: str
        """
        return self._node_operate_type

    @node_operate_type.setter
    def node_operate_type(self, node_operate_type):
        """Sets the node_operate_type of this NodeInfoForRestoreToNewInstanceInput.


        :param node_operate_type: The node_operate_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :type: str
        """

        self._node_operate_type = node_operate_type

    @property
    def node_spec(self):
        """Gets the node_spec of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501


        :return: The node_spec of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :rtype: str
        """
        return self._node_spec

    @node_spec.setter
    def node_spec(self, node_spec):
        """Sets the node_spec of this NodeInfoForRestoreToNewInstanceInput.


        :param node_spec: The node_spec of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :type: str
        """

        self._node_spec = node_spec

    @property
    def node_type(self):
        """Gets the node_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501


        :return: The node_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this NodeInfoForRestoreToNewInstanceInput.


        :param node_type: The node_type of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :type: str
        """

        self._node_type = node_type

    @property
    def zone_id(self):
        """Gets the zone_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501


        :return: The zone_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this NodeInfoForRestoreToNewInstanceInput.


        :param zone_id: The zone_id of this NodeInfoForRestoreToNewInstanceInput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeInfoForRestoreToNewInstanceInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeInfoForRestoreToNewInstanceInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeInfoForRestoreToNewInstanceInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NetworkInterfaceForDescribeInstancesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mac_address': 'str',
        'network_interface_id': 'str',
        'primary_ip_address': 'str',
        'subnet_id': 'str',
        'type': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'mac_address': 'MacAddress',
        'network_interface_id': 'NetworkInterfaceId',
        'primary_ip_address': 'PrimaryIpAddress',
        'subnet_id': 'SubnetId',
        'type': 'Type',
        'vpc_id': 'VpcId'
    }

    def __init__(self, mac_address=None, network_interface_id=None, primary_ip_address=None, subnet_id=None, type=None, vpc_id=None, _configuration=None):  # noqa: E501
        """NetworkInterfaceForDescribeInstancesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._mac_address = None
        self._network_interface_id = None
        self._primary_ip_address = None
        self._subnet_id = None
        self._type = None
        self._vpc_id = None
        self.discriminator = None

        if mac_address is not None:
            self.mac_address = mac_address
        if network_interface_id is not None:
            self.network_interface_id = network_interface_id
        if primary_ip_address is not None:
            self.primary_ip_address = primary_ip_address
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if type is not None:
            self.type = type
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def mac_address(self):
        """Gets the mac_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The mac_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._mac_address

    @mac_address.setter
    def mac_address(self, mac_address):
        """Sets the mac_address of this NetworkInterfaceForDescribeInstancesOutput.


        :param mac_address: The mac_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._mac_address = mac_address

    @property
    def network_interface_id(self):
        """Gets the network_interface_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The network_interface_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._network_interface_id

    @network_interface_id.setter
    def network_interface_id(self, network_interface_id):
        """Sets the network_interface_id of this NetworkInterfaceForDescribeInstancesOutput.


        :param network_interface_id: The network_interface_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._network_interface_id = network_interface_id

    @property
    def primary_ip_address(self):
        """Gets the primary_ip_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The primary_ip_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._primary_ip_address

    @primary_ip_address.setter
    def primary_ip_address(self, primary_ip_address):
        """Sets the primary_ip_address of this NetworkInterfaceForDescribeInstancesOutput.


        :param primary_ip_address: The primary_ip_address of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._primary_ip_address = primary_ip_address

    @property
    def subnet_id(self):
        """Gets the subnet_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The subnet_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this NetworkInterfaceForDescribeInstancesOutput.


        :param subnet_id: The subnet_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def type(self):
        """Gets the type of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The type of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this NetworkInterfaceForDescribeInstancesOutput.


        :param type: The type of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def vpc_id(self):
        """Gets the vpc_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501


        :return: The vpc_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this NetworkInterfaceForDescribeInstancesOutput.


        :param vpc_id: The vpc_id of this NetworkInterfaceForDescribeInstancesOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkInterfaceForDescribeInstancesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkInterfaceForDescribeInstancesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NetworkInterfaceForDescribeInstancesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    cen

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bandwidth': 'int',
        'cen_id': 'str',
        'creation_time': 'str',
        'inter_region_bandwidth_id': 'str',
        'local_region_id': 'str',
        'peer_region_id': 'str',
        'status': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'bandwidth': 'Bandwidth',
        'cen_id': 'CenId',
        'creation_time': 'CreationTime',
        'inter_region_bandwidth_id': 'InterRegionBandwidthId',
        'local_region_id': 'LocalRegionId',
        'peer_region_id': 'PeerRegionId',
        'status': 'Status',
        'update_time': 'UpdateTime'
    }

    def __init__(self, bandwidth=None, cen_id=None, creation_time=None, inter_region_bandwidth_id=None, local_region_id=None, peer_region_id=None, status=None, update_time=None, _configuration=None):  # noqa: E501
        """InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._bandwidth = None
        self._cen_id = None
        self._creation_time = None
        self._inter_region_bandwidth_id = None
        self._local_region_id = None
        self._peer_region_id = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if bandwidth is not None:
            self.bandwidth = bandwidth
        if cen_id is not None:
            self.cen_id = cen_id
        if creation_time is not None:
            self.creation_time = creation_time
        if inter_region_bandwidth_id is not None:
            self.inter_region_bandwidth_id = inter_region_bandwidth_id
        if local_region_id is not None:
            self.local_region_id = local_region_id
        if peer_region_id is not None:
            self.peer_region_id = peer_region_id
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def bandwidth(self):
        """Gets the bandwidth of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The bandwidth of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: int
        """
        return self._bandwidth

    @bandwidth.setter
    def bandwidth(self, bandwidth):
        """Sets the bandwidth of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param bandwidth: The bandwidth of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: int
        """

        self._bandwidth = bandwidth

    @property
    def cen_id(self):
        """Gets the cen_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The cen_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._cen_id

    @cen_id.setter
    def cen_id(self, cen_id):
        """Sets the cen_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param cen_id: The cen_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._cen_id = cen_id

    @property
    def creation_time(self):
        """Gets the creation_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The creation_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param creation_time: The creation_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def inter_region_bandwidth_id(self):
        """Gets the inter_region_bandwidth_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The inter_region_bandwidth_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._inter_region_bandwidth_id

    @inter_region_bandwidth_id.setter
    def inter_region_bandwidth_id(self, inter_region_bandwidth_id):
        """Sets the inter_region_bandwidth_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param inter_region_bandwidth_id: The inter_region_bandwidth_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._inter_region_bandwidth_id = inter_region_bandwidth_id

    @property
    def local_region_id(self):
        """Gets the local_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The local_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._local_region_id

    @local_region_id.setter
    def local_region_id(self, local_region_id):
        """Sets the local_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param local_region_id: The local_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._local_region_id = local_region_id

    @property
    def peer_region_id(self):
        """Gets the peer_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The peer_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._peer_region_id

    @peer_region_id.setter
    def peer_region_id(self, peer_region_id):
        """Sets the peer_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param peer_region_id: The peer_region_id of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._peer_region_id = peer_region_id

    @property
    def status(self):
        """Gets the status of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The status of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param status: The status of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501


        :return: The update_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.


        :param update_time: The update_time of this InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InterRegionBandwidthForDescribeCenInterRegionBandwidthsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ModifySecurityGroupRuleDescriptionsEgressRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cidr_ip': 'str',
        'description': 'str',
        'policy': 'str',
        'port_end': 'int',
        'port_start': 'int',
        'priority': 'int',
        'protocol': 'str',
        'security_group_id': 'str',
        'source_group_id': 'str'
    }

    attribute_map = {
        'cidr_ip': 'CidrIp',
        'description': 'Description',
        'policy': 'Policy',
        'port_end': 'PortEnd',
        'port_start': 'PortStart',
        'priority': 'Priority',
        'protocol': 'Protocol',
        'security_group_id': 'SecurityGroupId',
        'source_group_id': 'SourceGroupId'
    }

    def __init__(self, cidr_ip=None, description=None, policy=None, port_end=None, port_start=None, priority=None, protocol=None, security_group_id=None, source_group_id=None, _configuration=None):  # noqa: E501
        """ModifySecurityGroupRuleDescriptionsEgressRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cidr_ip = None
        self._description = None
        self._policy = None
        self._port_end = None
        self._port_start = None
        self._priority = None
        self._protocol = None
        self._security_group_id = None
        self._source_group_id = None
        self.discriminator = None

        if cidr_ip is not None:
            self.cidr_ip = cidr_ip
        if description is not None:
            self.description = description
        if policy is not None:
            self.policy = policy
        self.port_end = port_end
        self.port_start = port_start
        if priority is not None:
            self.priority = priority
        self.protocol = protocol
        self.security_group_id = security_group_id
        if source_group_id is not None:
            self.source_group_id = source_group_id

    @property
    def cidr_ip(self):
        """Gets the cidr_ip of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The cidr_ip of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._cidr_ip

    @cidr_ip.setter
    def cidr_ip(self, cidr_ip):
        """Sets the cidr_ip of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param cidr_ip: The cidr_ip of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """

        self._cidr_ip = cidr_ip

    @property
    def description(self):
        """Gets the description of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The description of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param description: The description of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def policy(self):
        """Gets the policy of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The policy of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param policy: The policy of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """

        self._policy = policy

    @property
    def port_end(self):
        """Gets the port_end of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The port_end of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: int
        """
        return self._port_end

    @port_end.setter
    def port_end(self, port_end):
        """Sets the port_end of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param port_end: The port_end of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and port_end is None:
            raise ValueError("Invalid value for `port_end`, must not be `None`")  # noqa: E501

        self._port_end = port_end

    @property
    def port_start(self):
        """Gets the port_start of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The port_start of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: int
        """
        return self._port_start

    @port_start.setter
    def port_start(self, port_start):
        """Sets the port_start of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param port_start: The port_start of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and port_start is None:
            raise ValueError("Invalid value for `port_start`, must not be `None`")  # noqa: E501

        self._port_start = port_start

    @property
    def priority(self):
        """Gets the priority of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The priority of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param priority: The priority of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def protocol(self):
        """Gets the protocol of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The protocol of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param protocol: The protocol of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and protocol is None:
            raise ValueError("Invalid value for `protocol`, must not be `None`")  # noqa: E501

        self._protocol = protocol

    @property
    def security_group_id(self):
        """Gets the security_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The security_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        """Sets the security_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param security_group_id: The security_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and security_group_id is None:
            raise ValueError("Invalid value for `security_group_id`, must not be `None`")  # noqa: E501

        self._security_group_id = security_group_id

    @property
    def source_group_id(self):
        """Gets the source_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501


        :return: The source_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :rtype: str
        """
        return self._source_group_id

    @source_group_id.setter
    def source_group_id(self, source_group_id):
        """Sets the source_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.


        :param source_group_id: The source_group_id of this ModifySecurityGroupRuleDescriptionsEgressRequest.  # noqa: E501
        :type: str
        """

        self._source_group_id = source_group_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModifySecurityGroupRuleDescriptionsEgressRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifySecurityGroupRuleDescriptionsEgressRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModifySecurityGroupRuleDescriptionsEgressRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    storage_ebs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkstorageebs.models.attach_volume_request import AttachVolumeRequest
from volcenginesdkstorageebs.models.attach_volume_response import AttachVolumeResponse
from volcenginesdkstorageebs.models.create_volume_request import CreateVolumeRequest
from volcenginesdkstorageebs.models.create_volume_response import CreateVolumeResponse
from volcenginesdkstorageebs.models.delete_volume_request import DeleteVolumeRequest
from volcenginesdkstorageebs.models.delete_volume_response import DeleteVolumeResponse
from volcenginesdkstorageebs.models.describe_volumes_request import DescribeVolumesRequest
from volcenginesdkstorageebs.models.describe_volumes_response import DescribeVolumesResponse
from volcenginesdkstorageebs.models.detach_volume_request import DetachVolumeRequest
from volcenginesdkstorageebs.models.detach_volume_response import DetachVolumeResponse
from volcenginesdkstorageebs.models.extend_volume_request import ExtendVolumeRequest
from volcenginesdkstorageebs.models.extend_volume_response import ExtendVolumeResponse
from volcenginesdkstorageebs.models.modify_volume_attribute_request import ModifyVolumeAttributeRequest
from volcenginesdkstorageebs.models.modify_volume_attribute_response import ModifyVolumeAttributeResponse
from volcenginesdkstorageebs.models.volume_for_describe_volumes_output import VolumeForDescribeVolumesOutput



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeRouteEntryListRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destination_cidr_block': 'str',
        'next_hop_id': 'str',
        'next_hop_type': 'str',
        'page_number': 'int',
        'page_size': 'int',
        'route_entry_id': 'str',
        'route_entry_name': 'str',
        'route_entry_type': 'str',
        'route_table_id': 'str'
    }

    attribute_map = {
        'destination_cidr_block': 'DestinationCidrBlock',
        'next_hop_id': 'NextHopId',
        'next_hop_type': 'NextHopType',
        'page_number': 'PageNumber',
        'page_size': 'PageSize',
        'route_entry_id': 'RouteEntryId',
        'route_entry_name': 'RouteEntryName',
        'route_entry_type': 'RouteEntryType',
        'route_table_id': 'RouteTableId'
    }

    def __init__(self, destination_cidr_block=None, next_hop_id=None, next_hop_type=None, page_number=None, page_size=None, route_entry_id=None, route_entry_name=None, route_entry_type=None, route_table_id=None, _configuration=None):  # noqa: E501
        """DescribeRouteEntryListRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._destination_cidr_block = None
        self._next_hop_id = None
        self._next_hop_type = None
        self._page_number = None
        self._page_size = None
        self._route_entry_id = None
        self._route_entry_name = None
        self._route_entry_type = None
        self._route_table_id = None
        self.discriminator = None

        if destination_cidr_block is not None:
            self.destination_cidr_block = destination_cidr_block
        if next_hop_id is not None:
            self.next_hop_id = next_hop_id
        if next_hop_type is not None:
            self.next_hop_type = next_hop_type
        if page_number is not None:
            self.page_number = page_number
        if page_size is not None:
            self.page_size = page_size
        if route_entry_id is not None:
            self.route_entry_id = route_entry_id
        if route_entry_name is not None:
            self.route_entry_name = route_entry_name
        if route_entry_type is not None:
            self.route_entry_type = route_entry_type
        self.route_table_id = route_table_id

    @property
    def destination_cidr_block(self):
        """Gets the destination_cidr_block of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The destination_cidr_block of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_cidr_block

    @destination_cidr_block.setter
    def destination_cidr_block(self, destination_cidr_block):
        """Sets the destination_cidr_block of this DescribeRouteEntryListRequest.


        :param destination_cidr_block: The destination_cidr_block of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._destination_cidr_block = destination_cidr_block

    @property
    def next_hop_id(self):
        """Gets the next_hop_id of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The next_hop_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._next_hop_id

    @next_hop_id.setter
    def next_hop_id(self, next_hop_id):
        """Sets the next_hop_id of this DescribeRouteEntryListRequest.


        :param next_hop_id: The next_hop_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._next_hop_id = next_hop_id

    @property
    def next_hop_type(self):
        """Gets the next_hop_type of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The next_hop_type of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._next_hop_type

    @next_hop_type.setter
    def next_hop_type(self, next_hop_type):
        """Sets the next_hop_type of this DescribeRouteEntryListRequest.


        :param next_hop_type: The next_hop_type of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._next_hop_type = next_hop_type

    @property
    def page_number(self):
        """Gets the page_number of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The page_number of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """Sets the page_number of this DescribeRouteEntryListRequest.


        :param page_number: The page_number of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: int
        """

        self._page_number = page_number

    @property
    def page_size(self):
        """Gets the page_size of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The page_size of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this DescribeRouteEntryListRequest.


        :param page_size: The page_size of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: int
        """
        if (self._configuration.client_side_validation and
                page_size is not None and page_size > 100):  # noqa: E501
            raise ValueError("Invalid value for `page_size`, must be a value less than or equal to `100`")  # noqa: E501

        self._page_size = page_size

    @property
    def route_entry_id(self):
        """Gets the route_entry_id of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The route_entry_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_entry_id

    @route_entry_id.setter
    def route_entry_id(self, route_entry_id):
        """Sets the route_entry_id of this DescribeRouteEntryListRequest.


        :param route_entry_id: The route_entry_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._route_entry_id = route_entry_id

    @property
    def route_entry_name(self):
        """Gets the route_entry_name of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The route_entry_name of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_entry_name

    @route_entry_name.setter
    def route_entry_name(self, route_entry_name):
        """Sets the route_entry_name of this DescribeRouteEntryListRequest.


        :param route_entry_name: The route_entry_name of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._route_entry_name = route_entry_name

    @property
    def route_entry_type(self):
        """Gets the route_entry_type of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The route_entry_type of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_entry_type

    @route_entry_type.setter
    def route_entry_type(self, route_entry_type):
        """Sets the route_entry_type of this DescribeRouteEntryListRequest.


        :param route_entry_type: The route_entry_type of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """

        self._route_entry_type = route_entry_type

    @property
    def route_table_id(self):
        """Gets the route_table_id of this DescribeRouteEntryListRequest.  # noqa: E501


        :return: The route_table_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """Sets the route_table_id of this DescribeRouteEntryListRequest.


        :param route_table_id: The route_table_id of this DescribeRouteEntryListRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and route_table_id is None:
            raise ValueError("Invalid value for `route_table_id`, must not be `None`")  # noqa: E501

        self._route_table_id = route_table_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeRouteEntryListRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeRouteEntryListRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeRouteEntryListRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ParamForDescribeDBInstanceParamsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_value': 'str',
        'default_value': 'str',
        'description': 'str',
        'editable_for_instance': 'bool',
        'need_reboot': 'bool',
        'options': 'list[OptionForDescribeDBInstanceParamsOutput]',
        'param_name': 'str',
        'range': 'str',
        'type': 'str',
        'unit': 'str'
    }

    attribute_map = {
        'current_value': 'CurrentValue',
        'default_value': 'DefaultValue',
        'description': 'Description',
        'editable_for_instance': 'EditableForInstance',
        'need_reboot': 'NeedReboot',
        'options': 'Options',
        'param_name': 'ParamName',
        'range': 'Range',
        'type': 'Type',
        'unit': 'Unit'
    }

    def __init__(self, current_value=None, default_value=None, description=None, editable_for_instance=None, need_reboot=None, options=None, param_name=None, range=None, type=None, unit=None, _configuration=None):  # noqa: E501
        """ParamForDescribeDBInstanceParamsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._current_value = None
        self._default_value = None
        self._description = None
        self._editable_for_instance = None
        self._need_reboot = None
        self._options = None
        self._param_name = None
        self._range = None
        self._type = None
        self._unit = None
        self.discriminator = None

        if current_value is not None:
            self.current_value = current_value
        if default_value is not None:
            self.default_value = default_value
        if description is not None:
            self.description = description
        if editable_for_instance is not None:
            self.editable_for_instance = editable_for_instance
        if need_reboot is not None:
            self.need_reboot = need_reboot
        if options is not None:
            self.options = options
        if param_name is not None:
            self.param_name = param_name
        if range is not None:
            self.range = range
        if type is not None:
            self.type = type
        if unit is not None:
            self.unit = unit

    @property
    def current_value(self):
        """Gets the current_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The current_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._current_value

    @current_value.setter
    def current_value(self, current_value):
        """Sets the current_value of this ParamForDescribeDBInstanceParamsOutput.


        :param current_value: The current_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._current_value = current_value

    @property
    def default_value(self):
        """Gets the default_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The default_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this ParamForDescribeDBInstanceParamsOutput.


        :param default_value: The default_value of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def description(self):
        """Gets the description of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The description of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ParamForDescribeDBInstanceParamsOutput.


        :param description: The description of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def editable_for_instance(self):
        """Gets the editable_for_instance of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The editable_for_instance of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: bool
        """
        return self._editable_for_instance

    @editable_for_instance.setter
    def editable_for_instance(self, editable_for_instance):
        """Sets the editable_for_instance of this ParamForDescribeDBInstanceParamsOutput.


        :param editable_for_instance: The editable_for_instance of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: bool
        """

        self._editable_for_instance = editable_for_instance

    @property
    def need_reboot(self):
        """Gets the need_reboot of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The need_reboot of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: bool
        """
        return self._need_reboot

    @need_reboot.setter
    def need_reboot(self, need_reboot):
        """Sets the need_reboot of this ParamForDescribeDBInstanceParamsOutput.


        :param need_reboot: The need_reboot of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: bool
        """

        self._need_reboot = need_reboot

    @property
    def options(self):
        """Gets the options of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The options of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: list[OptionForDescribeDBInstanceParamsOutput]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this ParamForDescribeDBInstanceParamsOutput.


        :param options: The options of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: list[OptionForDescribeDBInstanceParamsOutput]
        """

        self._options = options

    @property
    def param_name(self):
        """Gets the param_name of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The param_name of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._param_name

    @param_name.setter
    def param_name(self, param_name):
        """Sets the param_name of this ParamForDescribeDBInstanceParamsOutput.


        :param param_name: The param_name of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._param_name = param_name

    @property
    def range(self):
        """Gets the range of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The range of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._range

    @range.setter
    def range(self, range):
        """Sets the range of this ParamForDescribeDBInstanceParamsOutput.


        :param range: The range of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._range = range

    @property
    def type(self):
        """Gets the type of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The type of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ParamForDescribeDBInstanceParamsOutput.


        :param type: The type of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def unit(self):
        """Gets the unit of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501


        :return: The unit of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ParamForDescribeDBInstanceParamsOutput.


        :param unit: The unit of this ParamForDescribeDBInstanceParamsOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParamForDescribeDBInstanceParamsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParamForDescribeDBInstanceParamsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParamForDescribeDBInstanceParamsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ResourceTagForListTagsForResourcesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resource_id': 'str',
        'resource_type': 'str',
        'tag_key': 'str',
        'tag_value': 'str'
    }

    attribute_map = {
        'resource_id': 'ResourceId',
        'resource_type': 'ResourceType',
        'tag_key': 'TagKey',
        'tag_value': 'TagValue'
    }

    def __init__(self, resource_id=None, resource_type=None, tag_key=None, tag_value=None, _configuration=None):  # noqa: E501
        """ResourceTagForListTagsForResourcesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._resource_id = None
        self._resource_type = None
        self._tag_key = None
        self._tag_value = None
        self.discriminator = None

        if resource_id is not None:
            self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        if tag_key is not None:
            self.tag_key = tag_key
        if tag_value is not None:
            self.tag_value = tag_value

    @property
    def resource_id(self):
        """Gets the resource_id of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501


        :return: The resource_id of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this ResourceTagForListTagsForResourcesOutput.


        :param resource_id: The resource_id of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def resource_type(self):
        """Gets the resource_type of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501


        :return: The resource_type of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this ResourceTagForListTagsForResourcesOutput.


        :param resource_type: The resource_type of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def tag_key(self):
        """Gets the tag_key of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501


        :return: The tag_key of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this ResourceTagForListTagsForResourcesOutput.


        :param tag_key: The tag_key of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :type: str
        """

        self._tag_key = tag_key

    @property
    def tag_value(self):
        """Gets the tag_value of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501


        :return: The tag_value of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :rtype: str
        """
        return self._tag_value

    @tag_value.setter
    def tag_value(self, tag_value):
        """Sets the tag_value of this ResourceTagForListTagsForResourcesOutput.


        :param tag_value: The tag_value of this ResourceTagForListTagsForResourcesOutput.  # noqa: E501
        :type: str
        """

        self._tag_value = tag_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceTagForListTagsForResourcesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceTagForListTagsForResourcesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceTagForListTagsForResourcesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vke

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DeleteClusterRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cascading_delete_resources': 'list[str]',
        'force': 'bool',
        'id': 'str'
    }

    attribute_map = {
        'cascading_delete_resources': 'CascadingDeleteResources',
        'force': 'Force',
        'id': 'Id'
    }

    def __init__(self, cascading_delete_resources=None, force=None, id=None, _configuration=None):  # noqa: E501
        """DeleteClusterRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cascading_delete_resources = None
        self._force = None
        self._id = None
        self.discriminator = None

        if cascading_delete_resources is not None:
            self.cascading_delete_resources = cascading_delete_resources
        if force is not None:
            self.force = force
        if id is not None:
            self.id = id

    @property
    def cascading_delete_resources(self):
        """Gets the cascading_delete_resources of this DeleteClusterRequest.  # noqa: E501


        :return: The cascading_delete_resources of this DeleteClusterRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._cascading_delete_resources

    @cascading_delete_resources.setter
    def cascading_delete_resources(self, cascading_delete_resources):
        """Sets the cascading_delete_resources of this DeleteClusterRequest.


        :param cascading_delete_resources: The cascading_delete_resources of this DeleteClusterRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["Clb", "DefaultNodePoolResource", "Nat", "NodePoolResource", "TryBest"]  # noqa: E501
        if (self._configuration.client_side_validation and
                not set(cascading_delete_resources).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `cascading_delete_resources` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(cascading_delete_resources) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._cascading_delete_resources = cascading_delete_resources

    @property
    def force(self):
        """Gets the force of this DeleteClusterRequest.  # noqa: E501


        :return: The force of this DeleteClusterRequest.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force):
        """Sets the force of this DeleteClusterRequest.


        :param force: The force of this DeleteClusterRequest.  # noqa: E501
        :type: bool
        """

        self._force = force

    @property
    def id(self):
        """Gets the id of this DeleteClusterRequest.  # noqa: E501


        :return: The id of this DeleteClusterRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeleteClusterRequest.


        :param id: The id of this DeleteClusterRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeleteClusterRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteClusterRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeleteClusterRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class InstanceDetailForDescribeBackupsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'int',
        'arch_type': 'str',
        'charge_type': 'str',
        'engine_version': 'str',
        'expired_time': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'maintenance_time': 'str',
        'network_type': 'str',
        'project_name': 'str',
        'region_id': 'str',
        'replicas': 'int',
        'server_cpu': 'int',
        'shard_capacity': 'int',
        'shard_count': 'int',
        'total_capacity': 'int',
        'used_capacity': 'int',
        'vpc_info': 'VpcInfoForDescribeBackupsOutput',
        'zone_ids': 'list[str]'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'arch_type': 'ArchType',
        'charge_type': 'ChargeType',
        'engine_version': 'EngineVersion',
        'expired_time': 'ExpiredTime',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'maintenance_time': 'MaintenanceTime',
        'network_type': 'NetworkType',
        'project_name': 'ProjectName',
        'region_id': 'RegionId',
        'replicas': 'Replicas',
        'server_cpu': 'ServerCpu',
        'shard_capacity': 'ShardCapacity',
        'shard_count': 'ShardCount',
        'total_capacity': 'TotalCapacity',
        'used_capacity': 'UsedCapacity',
        'vpc_info': 'VpcInfo',
        'zone_ids': 'ZoneIds'
    }

    def __init__(self, account_id=None, arch_type=None, charge_type=None, engine_version=None, expired_time=None, instance_id=None, instance_name=None, maintenance_time=None, network_type=None, project_name=None, region_id=None, replicas=None, server_cpu=None, shard_capacity=None, shard_count=None, total_capacity=None, used_capacity=None, vpc_info=None, zone_ids=None, _configuration=None):  # noqa: E501
        """InstanceDetailForDescribeBackupsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._arch_type = None
        self._charge_type = None
        self._engine_version = None
        self._expired_time = None
        self._instance_id = None
        self._instance_name = None
        self._maintenance_time = None
        self._network_type = None
        self._project_name = None
        self._region_id = None
        self._replicas = None
        self._server_cpu = None
        self._shard_capacity = None
        self._shard_count = None
        self._total_capacity = None
        self._used_capacity = None
        self._vpc_info = None
        self._zone_ids = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if arch_type is not None:
            self.arch_type = arch_type
        if charge_type is not None:
            self.charge_type = charge_type
        if engine_version is not None:
            self.engine_version = engine_version
        if expired_time is not None:
            self.expired_time = expired_time
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if maintenance_time is not None:
            self.maintenance_time = maintenance_time
        if network_type is not None:
            self.network_type = network_type
        if project_name is not None:
            self.project_name = project_name
        if region_id is not None:
            self.region_id = region_id
        if replicas is not None:
            self.replicas = replicas
        if server_cpu is not None:
            self.server_cpu = server_cpu
        if shard_capacity is not None:
            self.shard_capacity = shard_capacity
        if shard_count is not None:
            self.shard_count = shard_count
        if total_capacity is not None:
            self.total_capacity = total_capacity
        if used_capacity is not None:
            self.used_capacity = used_capacity
        if vpc_info is not None:
            self.vpc_info = vpc_info
        if zone_ids is not None:
            self.zone_ids = zone_ids

    @property
    def account_id(self):
        """Gets the account_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The account_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this InstanceDetailForDescribeBackupsOutput.


        :param account_id: The account_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def arch_type(self):
        """Gets the arch_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The arch_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._arch_type

    @arch_type.setter
    def arch_type(self, arch_type):
        """Sets the arch_type of this InstanceDetailForDescribeBackupsOutput.


        :param arch_type: The arch_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._arch_type = arch_type

    @property
    def charge_type(self):
        """Gets the charge_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The charge_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this InstanceDetailForDescribeBackupsOutput.


        :param charge_type: The charge_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._charge_type = charge_type

    @property
    def engine_version(self):
        """Gets the engine_version of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The engine_version of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._engine_version

    @engine_version.setter
    def engine_version(self, engine_version):
        """Sets the engine_version of this InstanceDetailForDescribeBackupsOutput.


        :param engine_version: The engine_version of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._engine_version = engine_version

    @property
    def expired_time(self):
        """Gets the expired_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The expired_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this InstanceDetailForDescribeBackupsOutput.


        :param expired_time: The expired_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def instance_id(self):
        """Gets the instance_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The instance_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this InstanceDetailForDescribeBackupsOutput.


        :param instance_id: The instance_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The instance_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this InstanceDetailForDescribeBackupsOutput.


        :param instance_name: The instance_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def maintenance_time(self):
        """Gets the maintenance_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The maintenance_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_time

    @maintenance_time.setter
    def maintenance_time(self, maintenance_time):
        """Sets the maintenance_time of this InstanceDetailForDescribeBackupsOutput.


        :param maintenance_time: The maintenance_time of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._maintenance_time = maintenance_time

    @property
    def network_type(self):
        """Gets the network_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The network_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._network_type

    @network_type.setter
    def network_type(self, network_type):
        """Sets the network_type of this InstanceDetailForDescribeBackupsOutput.


        :param network_type: The network_type of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._network_type = network_type

    @property
    def project_name(self):
        """Gets the project_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The project_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this InstanceDetailForDescribeBackupsOutput.


        :param project_name: The project_name of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def region_id(self):
        """Gets the region_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The region_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this InstanceDetailForDescribeBackupsOutput.


        :param region_id: The region_id of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def replicas(self):
        """Gets the replicas of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The replicas of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """Sets the replicas of this InstanceDetailForDescribeBackupsOutput.


        :param replicas: The replicas of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._replicas = replicas

    @property
    def server_cpu(self):
        """Gets the server_cpu of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The server_cpu of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._server_cpu

    @server_cpu.setter
    def server_cpu(self, server_cpu):
        """Sets the server_cpu of this InstanceDetailForDescribeBackupsOutput.


        :param server_cpu: The server_cpu of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._server_cpu = server_cpu

    @property
    def shard_capacity(self):
        """Gets the shard_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The shard_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._shard_capacity

    @shard_capacity.setter
    def shard_capacity(self, shard_capacity):
        """Sets the shard_capacity of this InstanceDetailForDescribeBackupsOutput.


        :param shard_capacity: The shard_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._shard_capacity = shard_capacity

    @property
    def shard_count(self):
        """Gets the shard_count of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The shard_count of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._shard_count

    @shard_count.setter
    def shard_count(self, shard_count):
        """Sets the shard_count of this InstanceDetailForDescribeBackupsOutput.


        :param shard_count: The shard_count of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._shard_count = shard_count

    @property
    def total_capacity(self):
        """Gets the total_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The total_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._total_capacity

    @total_capacity.setter
    def total_capacity(self, total_capacity):
        """Sets the total_capacity of this InstanceDetailForDescribeBackupsOutput.


        :param total_capacity: The total_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._total_capacity = total_capacity

    @property
    def used_capacity(self):
        """Gets the used_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The used_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: int
        """
        return self._used_capacity

    @used_capacity.setter
    def used_capacity(self, used_capacity):
        """Sets the used_capacity of this InstanceDetailForDescribeBackupsOutput.


        :param used_capacity: The used_capacity of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: int
        """

        self._used_capacity = used_capacity

    @property
    def vpc_info(self):
        """Gets the vpc_info of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The vpc_info of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: VpcInfoForDescribeBackupsOutput
        """
        return self._vpc_info

    @vpc_info.setter
    def vpc_info(self, vpc_info):
        """Sets the vpc_info of this InstanceDetailForDescribeBackupsOutput.


        :param vpc_info: The vpc_info of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: VpcInfoForDescribeBackupsOutput
        """

        self._vpc_info = vpc_info

    @property
    def zone_ids(self):
        """Gets the zone_ids of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501


        :return: The zone_ids of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._zone_ids

    @zone_ids.setter
    def zone_ids(self, zone_ids):
        """Sets the zone_ids of this InstanceDetailForDescribeBackupsOutput.


        :param zone_ids: The zone_ids of this InstanceDetailForDescribeBackupsOutput.  # noqa: E501
        :type: list[str]
        """

        self._zone_ids = zone_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstanceDetailForDescribeBackupsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstanceDetailForDescribeBackupsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstanceDetailForDescribeBackupsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class NodeForDescribeDBInstanceDetailOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'create_time': 'str',
        'instance_id': 'str',
        'memory': 'int',
        'node_id': 'str',
        'node_spec': 'str',
        'node_status': 'str',
        'node_type': 'str',
        'region_id': 'str',
        'update_time': 'str',
        'vcpu': 'int',
        'zone_id': 'str'
    }

    attribute_map = {
        'create_time': 'CreateTime',
        'instance_id': 'InstanceId',
        'memory': 'Memory',
        'node_id': 'NodeId',
        'node_spec': 'NodeSpec',
        'node_status': 'NodeStatus',
        'node_type': 'NodeType',
        'region_id': 'RegionId',
        'update_time': 'UpdateTime',
        'vcpu': 'VCPU',
        'zone_id': 'ZoneId'
    }

    def __init__(self, create_time=None, instance_id=None, memory=None, node_id=None, node_spec=None, node_status=None, node_type=None, region_id=None, update_time=None, vcpu=None, zone_id=None, _configuration=None):  # noqa: E501
        """NodeForDescribeDBInstanceDetailOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._create_time = None
        self._instance_id = None
        self._memory = None
        self._node_id = None
        self._node_spec = None
        self._node_status = None
        self._node_type = None
        self._region_id = None
        self._update_time = None
        self._vcpu = None
        self._zone_id = None
        self.discriminator = None

        if create_time is not None:
            self.create_time = create_time
        if instance_id is not None:
            self.instance_id = instance_id
        if memory is not None:
            self.memory = memory
        if node_id is not None:
            self.node_id = node_id
        if node_spec is not None:
            self.node_spec = node_spec
        if node_status is not None:
            self.node_status = node_status
        if node_type is not None:
            self.node_type = node_type
        if region_id is not None:
            self.region_id = region_id
        if update_time is not None:
            self.update_time = update_time
        if vcpu is not None:
            self.vcpu = vcpu
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def create_time(self):
        """Gets the create_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The create_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this NodeForDescribeDBInstanceDetailOutput.


        :param create_time: The create_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def instance_id(self):
        """Gets the instance_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The instance_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this NodeForDescribeDBInstanceDetailOutput.


        :param instance_id: The instance_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def memory(self):
        """Gets the memory of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The memory of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: int
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this NodeForDescribeDBInstanceDetailOutput.


        :param memory: The memory of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: int
        """

        self._memory = memory

    @property
    def node_id(self):
        """Gets the node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this NodeForDescribeDBInstanceDetailOutput.


        :param node_id: The node_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def node_spec(self):
        """Gets the node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_spec

    @node_spec.setter
    def node_spec(self, node_spec):
        """Sets the node_spec of this NodeForDescribeDBInstanceDetailOutput.


        :param node_spec: The node_spec of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_spec = node_spec

    @property
    def node_status(self):
        """Gets the node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_status

    @node_status.setter
    def node_status(self, node_status):
        """Sets the node_status of this NodeForDescribeDBInstanceDetailOutput.


        :param node_status: The node_status of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_status = node_status

    @property
    def node_type(self):
        """Gets the node_type of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The node_type of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this NodeForDescribeDBInstanceDetailOutput.


        :param node_type: The node_type of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._node_type = node_type

    @property
    def region_id(self):
        """Gets the region_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The region_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this NodeForDescribeDBInstanceDetailOutput.


        :param region_id: The region_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._region_id = region_id

    @property
    def update_time(self):
        """Gets the update_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The update_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this NodeForDescribeDBInstanceDetailOutput.


        :param update_time: The update_time of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def vcpu(self):
        """Gets the vcpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The vcpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: int
        """
        return self._vcpu

    @vcpu.setter
    def vcpu(self, vcpu):
        """Sets the vcpu of this NodeForDescribeDBInstanceDetailOutput.


        :param vcpu: The vcpu of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: int
        """

        self._vcpu = vcpu

    @property
    def zone_id(self):
        """Gets the zone_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The zone_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this NodeForDescribeDBInstanceDetailOutput.


        :param zone_id: The zone_id of this NodeForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeForDescribeDBInstanceDetailOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeForDescribeDBInstanceDetailOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NodeForDescribeDBInstanceDetailOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

from setuptools import setup, find_packages  # noqa: H301

NAME = "volcengine-python-sdk"
VERSION = "1.0.7"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]

setup(
    name=NAME,
    version=VERSION,
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    description='Volcengine SDK for Python',
    license="Apache License 2.0",
    platforms='any',
    url='https://github.com/volcengine/volcengine-python-sdk',
)



# coding: utf-8

"""
    rds_mysql

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ModifyParameterTemplateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'template_desc': 'str',
        'template_id': 'str',
        'template_name': 'str',
        'template_params': 'list[TemplateParamForModifyParameterTemplateInput]'
    }

    attribute_map = {
        'template_desc': 'TemplateDesc',
        'template_id': 'TemplateId',
        'template_name': 'TemplateName',
        'template_params': 'TemplateParams'
    }

    def __init__(self, template_desc=None, template_id=None, template_name=None, template_params=None, _configuration=None):  # noqa: E501
        """ModifyParameterTemplateRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._template_desc = None
        self._template_id = None
        self._template_name = None
        self._template_params = None
        self.discriminator = None

        if template_desc is not None:
            self.template_desc = template_desc
        self.template_id = template_id
        if template_name is not None:
            self.template_name = template_name
        if template_params is not None:
            self.template_params = template_params

    @property
    def template_desc(self):
        """Gets the template_desc of this ModifyParameterTemplateRequest.  # noqa: E501


        :return: The template_desc of this ModifyParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_desc

    @template_desc.setter
    def template_desc(self, template_desc):
        """Sets the template_desc of this ModifyParameterTemplateRequest.


        :param template_desc: The template_desc of this ModifyParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                template_desc is not None and len(template_desc) > 200):
            raise ValueError("Invalid value for `template_desc`, length must be less than or equal to `200`")  # noqa: E501

        self._template_desc = template_desc

    @property
    def template_id(self):
        """Gets the template_id of this ModifyParameterTemplateRequest.  # noqa: E501


        :return: The template_id of this ModifyParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this ModifyParameterTemplateRequest.


        :param template_id: The template_id of this ModifyParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and template_id is None:
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def template_name(self):
        """Gets the template_name of this ModifyParameterTemplateRequest.  # noqa: E501


        :return: The template_name of this ModifyParameterTemplateRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this ModifyParameterTemplateRequest.


        :param template_name: The template_name of this ModifyParameterTemplateRequest.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                template_name is not None and len(template_name) > 64):
            raise ValueError("Invalid value for `template_name`, length must be less than or equal to `64`")  # noqa: E501
        if (self._configuration.client_side_validation and
                template_name is not None and len(template_name) < 2):
            raise ValueError("Invalid value for `template_name`, length must be greater than or equal to `2`")  # noqa: E501

        self._template_name = template_name

    @property
    def template_params(self):
        """Gets the template_params of this ModifyParameterTemplateRequest.  # noqa: E501


        :return: The template_params of this ModifyParameterTemplateRequest.  # noqa: E501
        :rtype: list[TemplateParamForModifyParameterTemplateInput]
        """
        return self._template_params

    @template_params.setter
    def template_params(self, template_params):
        """Sets the template_params of this ModifyParameterTemplateRequest.


        :param template_params: The template_params of this ModifyParameterTemplateRequest.  # noqa: E501
        :type: list[TemplateParamForModifyParameterTemplateInput]
        """

        self._template_params = template_params

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModifyParameterTemplateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyParameterTemplateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModifyParameterTemplateRequest):
            return True

        return self.to_dict() != other.to_dict()
